Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Park ¶
type Park struct {
ID bson.ObjectId `json:"id"`
AppUserID bson.ObjectId `json:"appUserID"`
Address string `json:"address"`
Status int `json:"status"`
Position Point `json:"position"`
Slots []Slot `json:"slots"`
}
Park struct
type Point ¶
Point contains the left-upper and bottom-lower points of a rectangle in which an entire zone is located
type Slot ¶
type Slot struct {
ID bson.ObjectId `json:"id"`
Park Park `json:"park"`
Position Point `json:"position"`
IsOccupied bool `json:"isOccupied"`
}
Slot reprents a square in a parking lot, where the car is parked
type SlotUpdate ¶
Click to show internal directories.
Click to hide internal directories.